==> ejc-zjkjcost-impl-3.0.0-20221104.023324-87-sources.jar: com/ejianc/business/zjkjcost/finish/bean/ApproveEntity.java <==
package com.ejianc.business.zjkjcost.finish.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 竣工考核-目标责任书竣工兑现审批-主表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_finish_approve")
public class ApproveEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="apply_id")
    private Long applyId; // 申报主表id
    @TableField(value="apply_code")
    private Long applyCode; // 申报主表code
    @TableField(value="contract_id")
    private Long contractId; // 合同主键
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同code
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="accord")
    private String accord; // 依据
    @TableField(value="department_cash_mny")
    private BigDecimal departmentCashMny; // 所属单位商务管理部意见兑现金额
    @TableField(value="capital_deduct_mny")
    private BigDecimal capitalDeductMny; // 所属单位财务资金部扣款金额
    @TableField(value="build_deduct_mny")
    private BigDecimal buildDeductMny; // 所属单位建造管理部扣款金额
    @TableField(value="technology_deduct_mny")
    private BigDecimal technologyDeductMny; // 所属单位工程技术中心扣款金额
    @TableField(value="design_deduct_mny")
    private BigDecimal designDeductMny; // 所属单位设计中心扣款金额
    @TableField(value="leader_cash_mny")
    private BigDecimal leaderCashMny; // 所属单位分管领导审核兑现金额
    @TableField(value="manager_cash_mny")
    private BigDecimal managerCashMny; //  所属单位总经理审批兑现金额
    @TableField(value="chairman_cash_mny")
    private BigDecimal chairmanCashMny; // 所属单位董事长审批兑现金额
    @TableField(value="safety_product_mny")
    private BigDecimal safetyProductMny; // 所属安全生产监督管理部扣款金额
    @TableField(value="office_approval_mny")
    private BigDecimal officeApprovalMny; // 所属综合办公室审批流扣款金额
    @TableField(value="calculation_process")
    private String calculationProcess; // 计算过程
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）

    public String getCalculationProcess() {
        return calculationProcess;
    }

    public void setCalculationProcess(String calculationProcess) {
        this.calculationProcess = calculationProcess;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }


    public BigDecimal getSafetyProductMny() {
        return safetyProductMny;
    }

    public void setSafetyProductMny(BigDecimal safetyProductMny) {
        this.safetyProductMny = safetyProductMny;
    }

    public BigDecimal getOfficeApprovalMny() {
        return officeApprovalMny;
    }

    public void setOfficeApprovalMny(BigDecimal officeApprovalMny) {
        this.officeApprovalMny = officeApprovalMny;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public Long getApplyCode() {
        return applyCode;
    }

    public void setApplyCode(Long applyCode) {
        this.applyCode = applyCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getAccord() {
        return accord;
    }

    public void setAccord(String accord) {
        this.accord = accord;
    }
    public BigDecimal getDepartmentCashMny() {
        return departmentCashMny;
    }

    public void setDepartmentCashMny(BigDecimal departmentCashMny) {
        this.departmentCashMny = departmentCashMny;
    }
    public BigDecimal getCapitalDeductMny() {
        return capitalDeductMny;
    }

    public void setCapitalDeductMny(BigDecimal capitalDeductMny) {
        this.capitalDeductMny = capitalDeductMny;
    }
    public BigDecimal getBuildDeductMny() {
        return buildDeductMny;
    }

    public void setBuildDeductMny(BigDecimal buildDeductMny) {
        this.buildDeductMny = buildDeductMny;
    }
    public BigDecimal getTechnologyDeductMny() {
        return technologyDeductMny;
    }

    public void setTechnologyDeductMny(BigDecimal technologyDeductMny) {
        this.technologyDeductMny = technologyDeductMny;
    }
    public BigDecimal getDesignDeductMny() {
        return designDeductMny;
    }

    public void setDesignDeductMny(BigDecimal designDeductMny) {
        this.designDeductMny = designDeductMny;
    }
    public BigDecimal getLeaderCashMny() {
        return leaderCashMny;
    }

    public void setLeaderCashMny(BigDecimal leaderCashMny) {
        this.leaderCashMny = leaderCashMny;
    }
    public BigDecimal getManagerCashMny() {
        return managerCashMny;
    }

    public void setManagerCashMny(BigDecimal managerCashMny) {
        this.managerCashMny = managerCashMny;
    }
    public BigDecimal getChairmanCashMny() {
        return chairmanCashMny;
    }

    public void setChairmanCashMny(BigDecimal chairmanCashMny) {
        this.chairmanCashMny = chairmanCashMny;
    }
    
}

==> ejc-zjkjcost-impl-3.0.0-20221209.102038-112-sources.jar: com/ejianc/business/zjkjcost/finish/bean/ApproveEntity.java <==
package com.ejianc.business.zjkjcost.finish.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 竣工考核-目标责任书竣工兑现审批-主表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_finish_approve")
public class ApproveEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="apply_id")
    private Long applyId; // 申报主表id
    @TableField(value="apply_code")
    private Long applyCode; // 申报主表code
    @TableField(value="contract_id")
    private Long contractId; // 合同主键
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同code
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="accord")
    private String accord; // 依据
    @TableField(value="department_cash_mny")
    private BigDecimal departmentCashMny; // 所属单位商务管理部意见兑现金额
    @TableField(value="capital_deduct_mny")
    private BigDecimal capitalDeductMny; // 所属单位财务资金部扣款金额
    @TableField(value="build_deduct_mny")
    private BigDecimal buildDeductMny; // 所属单位建造管理部扣款金额
    @TableField(value="technology_deduct_mny")
    private BigDecimal technologyDeductMny; // 所属单位工程技术中心扣款金额
    @TableField(value="design_deduct_mny")
    private BigDecimal designDeductMny; // 所属单位设计中心扣款金额
    @TableField(value="leader_cash_mny")
    private BigDecimal leaderCashMny; // 所属单位分管领导审核兑现金额
    @TableField(value="manager_cash_mny")
    private BigDecimal managerCashMny; //  所属单位总经理审批兑现金额
    @TableField(value="chairman_cash_mny")
    private BigDecimal chairmanCashMny; // 所属单位董事长审批兑现金额
    @TableField(value="safety_product_mny")
    private BigDecimal safetyProductMny; // 所属安全生产监督管理部扣款金额
    @TableField(value="office_approval_mny")
    private BigDecimal officeApprovalMny; // 所属综合办公室审批流扣款金额
    @TableField(value="calculation_process")
    private String calculationProcess; // 计算过程
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）

    @TableField(value="department_cash_opinion")
    private String departmentCashOpinion; // 所属单位商务管理部意见审批意见
    @TableField(value="capital_deduct_opinion")
    private String capitalDeductOpinion; // 所属单位财务资金部审批意见
    @TableField(value="build_deduct_opinion")
    private String buildDeductOpinion; // 所属单位建造管理部审批意见
    @TableField(value="technology_deduct_opinion")
    private String technologyDeductOpinion; // 所属单位工程技术中心审批意见
    @TableField(value="design_deduct_opinion")
    private String designDeductOpinion; // 所属单位设计中心审批意见
    @TableField(value="safety_product_opinion")
    private String safetyProductOpinion; // 所属安全生产监督管理部审批意见
    @TableField(value="office_approval_opinion")
    private String officeApprovalOpinion; // 所属综合办公室审批流审批意见
    @TableField(value="leader_cash_opinion")
    private String leaderCashOpinion; // 所属单位分管领导审核审批意见
    @TableField(value="manager_cash_opinion")
    private String managerCashOpinion; // 所属单位总经理审批审批意见
    @TableField(value="chairman_cash_opinion")
    private String chairmanCashOpinion; // 所属单位董事长审批审批意见


    public String getDepartmentCashOpinion() {
        return departmentCashOpinion;
    }

    public void setDepartmentCashOpinion(String departmentCashOpinion) {
        this.departmentCashOpinion = departmentCashOpinion;
    }

    public String getCapitalDeductOpinion() {
        return capitalDeductOpinion;
    }

    public void setCapitalDeductOpinion(String capitalDeductOpinion) {
        this.capitalDeductOpinion = capitalDeductOpinion;
    }

    public String getBuildDeductOpinion() {
        return buildDeductOpinion;
    }

    public void setBuildDeductOpinion(String buildDeductOpinion) {
        this.buildDeductOpinion = buildDeductOpinion;
    }

    public String getTechnologyDeductOpinion() {
        return technologyDeductOpinion;
    }

    public void setTechnologyDeductOpinion(String technologyDeductOpinion) {
        this.technologyDeductOpinion = technologyDeductOpinion;
    }

    public String getDesignDeductOpinion() {
        return designDeductOpinion;
    }

    public void setDesignDeductOpinion(String designDeductOpinion) {
        this.designDeductOpinion = designDeductOpinion;
    }

    public String getSafetyProductOpinion() {
        return safetyProductOpinion;
    }

    public void setSafetyProductOpinion(String safetyProductOpinion) {
        this.safetyProductOpinion = safetyProductOpinion;
    }

    public String getOfficeApprovalOpinion() {
        return officeApprovalOpinion;
    }

    public void setOfficeApprovalOpinion(String officeApprovalOpinion) {
        this.officeApprovalOpinion = officeApprovalOpinion;
    }

    public String getLeaderCashOpinion() {
        return leaderCashOpinion;
    }

    public void setLeaderCashOpinion(String leaderCashOpinion) {
        this.leaderCashOpinion = leaderCashOpinion;
    }

    public String getManagerCashOpinion() {
        return managerCashOpinion;
    }

    public void setManagerCashOpinion(String managerCashOpinion) {
        this.managerCashOpinion = managerCashOpinion;
    }

    public String getChairmanCashOpinion() {
        return chairmanCashOpinion;
    }

    public void setChairmanCashOpinion(String chairmanCashOpinion) {
        this.chairmanCashOpinion = chairmanCashOpinion;
    }

    public String getCalculationProcess() {
        return calculationProcess;
    }

    public void setCalculationProcess(String calculationProcess) {
        this.calculationProcess = calculationProcess;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }


    public BigDecimal getSafetyProductMny() {
        return safetyProductMny;
    }

    public void setSafetyProductMny(BigDecimal safetyProductMny) {
        this.safetyProductMny = safetyProductMny;
    }

    public BigDecimal getOfficeApprovalMny() {
        return officeApprovalMny;
    }

    public void setOfficeApprovalMny(BigDecimal officeApprovalMny) {
        this.officeApprovalMny = officeApprovalMny;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public Long getApplyCode() {
        return applyCode;
    }

    public void setApplyCode(Long applyCode) {
        this.applyCode = applyCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getAccord() {
        return accord;
    }

    public void setAccord(String accord) {
        this.accord = accord;
    }
    public BigDecimal getDepartmentCashMny() {
        return departmentCashMny;
    }

    public void setDepartmentCashMny(BigDecimal departmentCashMny) {
        this.departmentCashMny = departmentCashMny;
    }
    public BigDecimal getCapitalDeductMny() {
        return capitalDeductMny;
    }

    public void setCapitalDeductMny(BigDecimal capitalDeductMny) {
        this.capitalDeductMny = capitalDeductMny;
    }
    public BigDecimal getBuildDeductMny() {
        return buildDeductMny;
    }

    public void setBuildDeductMny(BigDecimal buildDeductMny) {
        this.buildDeductMny = buildDeductMny;
    }
    public BigDecimal getTechnologyDeductMny() {
        return technologyDeductMny;
    }

    public void setTechnologyDeductMny(BigDecimal technologyDeductMny) {
        this.technologyDeductMny = technologyDeductMny;
    }
    public BigDecimal getDesignDeductMny() {
        return designDeductMny;
    }

    public void setDesignDeductMny(BigDecimal designDeductMny) {
        this.designDeductMny = designDeductMny;
    }
    public BigDecimal getLeaderCashMny() {
        return leaderCashMny;
    }

    public void setLeaderCashMny(BigDecimal leaderCashMny) {
        this.leaderCashMny = leaderCashMny;
    }
    public BigDecimal getManagerCashMny() {
        return managerCashMny;
    }

    public void setManagerCashMny(BigDecimal managerCashMny) {
        this.managerCashMny = managerCashMny;
    }
    public BigDecimal getChairmanCashMny() {
        return chairmanCashMny;
    }

    public void setChairmanCashMny(BigDecimal chairmanCashMny) {
        this.chairmanCashMny = chairmanCashMny;
    }
    
}
